@@ -9,15 +9,16 @@
 #include <custom_conf.h>
 #else
 #define PROTOCOL_VERSION		10
-#define MYSQL_SERVER_VERSION		"5.0.41"
-#define MYSQL_BASE_VERSION		"mysqld-5.0"
-#define MYSQL_SERVER_SUFFIX_DEF		"-community"
+#define MYSQL_SERVER_VERSION		"5.1.65"
+#define MYSQL_BASE_VERSION		"mysqld-5.1"
+#define MYSQL_SERVER_SUFFIX_DEF		""
 #define FRM_VER				6
-#define MYSQL_VERSION_ID		50041
+#define MYSQL_VERSION_ID		50165
 #define MYSQL_PORT			3306
+#define MYSQL_PORT_DEFAULT		0
 #define MYSQL_UNIX_ADDR			"/var/lib/mysql/mysql.sock"
 #define MYSQL_CONFIG_NAME		"my"
-#define MYSQL_COMPILATION_COMMENT	"MySQL Community Edition (GPL)"
+#define MYSQL_COMPILATION_COMMENT	"MySQL Community Server (GPL)"
 
 /* mysqld compile time options */
 #endif /* _CUSTOMCONFIG_ */
